@@ -12,9 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General
- * Public License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Public License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -24,13 +22,14 @@
 G_BEGIN_DECLS
 
 #define OSTREE_TYPE_BOOTLOADER_ZIPL (_ostree_bootloader_zipl_get_type ())
-#define OSTREE_BOOTLOADER_ZIPL(inst) (G_TYPE_CHECK_INSTANCE_CAST ((inst), OSTREE_TYPE_BOOTLOADER_ZIPL, OstreeBootloaderZipl))
-#define OSTREE_IS_BOOTLOADER_ZIPL(inst) (G_TYPE_CHECK_INSTANCE_TYPE ((inst), OSTREE_TYPE_BOOTLOADER_ZIPL))
+#define OSTREE_BOOTLOADER_ZIPL(inst) \
+  (G_TYPE_CHECK_INSTANCE_CAST ((inst), OSTREE_TYPE_BOOTLOADER_ZIPL, OstreeBootloaderZipl))
+#define OSTREE_IS_BOOTLOADER_ZIPL(inst) \
+  (G_TYPE_CHECK_INSTANCE_TYPE ((inst), OSTREE_TYPE_BOOTLOADER_ZIPL))
 
 typedef struct _OstreeBootloaderZipl OstreeBootloaderZipl;
 
 GType _ostree_bootloader_zipl_get_type (void) G_GNUC_CONST;
 
-OstreeBootloaderZipl * _ostree_bootloader_zipl_new (OstreeSysroot *sysroot);
-
+OstreeBootloaderZipl *_ostree_bootloader_zipl_new (OstreeSysroot *sysroot);
 G_END_DECLS
