@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -26,11 +24,12 @@
 G_BEGIN_DECLS
 
 #define OSTREE_TYPE_CONTENT_WRITER (ostree_content_writer_get_type ())
-_OSTREE_PUBLIC G_DECLARE_FINAL_TYPE (OstreeContentWriter, ostree_content_writer, OSTREE, CONTENT_WRITER, GOutputStream)
+_OSTREE_PUBLIC
+G_DECLARE_FINAL_TYPE (OstreeContentWriter, ostree_content_writer, OSTREE, CONTENT_WRITER,
+                      GOutputStream)
 
 _OSTREE_PUBLIC
-char * ostree_content_writer_finish (OstreeContentWriter  *self,
-                                     GCancellable         *cancellable,
-                                     GError              **error);
+char *ostree_content_writer_finish (OstreeContentWriter *self, GCancellable *cancellable,
+                                    GError **error);
 
 G_END_DECLS
